==> codelite_6.1.1+dfsg.orig.tar.gz: codelite-6.1.1/git/gitCommitEditor.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2014 The CodeLite Team
// file name            : gitCommitEditor.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2011 by René Kraus (aka upCASE)
//
//////////////////////////////////////////////////////////////////////////////

#ifndef __gitCommitEditor__
#define __gitCommitEditor__

#include <wx/wx.h>
#include <wx/stc/stc.h>

class GitCommitEditor : public wxStyledTextCtrl
{
public:
    GitCommitEditor(wxWindow* parent, wxWindowID id = wxID_ANY, const wxPoint &position = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = 0);
    void InitStyles();
};

#endif //__gitCommitEditor__

==> codelite_10.0+dfsg.orig.tar.gz: codelite-10.0/git/gitCommitEditor.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2014 Eran Ifrah
// file name            : gitCommitEditor.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2011 by René Kraus (aka upCASE)
//
//////////////////////////////////////////////////////////////////////////////

#ifndef __gitCommitEditor__
#define __gitCommitEditor__

#include <wx/wx.h>
#include <wx/stc/stc.h>

class GitCommitEditor : public wxStyledTextCtrl
{
public:
    GitCommitEditor(wxWindow* parent,
                    wxWindowID id = wxID_ANY,
                    const wxPoint& position = wxDefaultPosition,
                    const wxSize& size = wxDefaultSize,
                    long style = 0);
    void InitStyles();
};

#endif //__gitCommitEditor__
